You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hc.apache.org by ol...@apache.org on 2017/05/09 19:58:13 UTC

[21/50] [abbrv] httpcomponents-core git commit: Fix Javadoc.

Fix Javadoc.

git-svn-id: https://svn.apache.org/repos/asf/httpcomponents/httpcore/trunk@1792539 13f79535-47bb-0310-9956-ffa450edef68


Project: http://git-wip-us.apache.org/repos/asf/httpcomponents-core/repo
Commit: http://git-wip-us.apache.org/repos/asf/httpcomponents-core/commit/4c3fd51a
Tree: http://git-wip-us.apache.org/repos/asf/httpcomponents-core/tree/4c3fd51a
Diff: http://git-wip-us.apache.org/repos/asf/httpcomponents-core/diff/4c3fd51a

Branch: refs/heads/trunk
Commit: 4c3fd51a05de974abfa08bd0e37dca1c9997a3e4
Parents: 401ab24
Author: Gary D. Gregory <gg...@apache.org>
Authored: Mon Apr 24 19:46:20 2017 +0000
Committer: Gary D. Gregory <gg...@apache.org>
Committed: Mon Apr 24 19:46:20 2017 +0000

----------------------------------------------------------------------
 .../java/org/apache/hc/core5/http/protocol/LookupRegistry.java   | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/httpcomponents-core/blob/4c3fd51a/httpcore5/src/main/java/org/apache/hc/core5/http/protocol/LookupRegistry.java
----------------------------------------------------------------------
diff --git a/httpcore5/src/main/java/org/apache/hc/core5/http/protocol/LookupRegistry.java b/httpcore5/src/main/java/org/apache/hc/core5/http/protocol/LookupRegistry.java
index 17b0021..d37b2c0 100644
--- a/httpcore5/src/main/java/org/apache/hc/core5/http/protocol/LookupRegistry.java
+++ b/httpcore5/src/main/java/org/apache/hc/core5/http/protocol/LookupRegistry.java
@@ -44,10 +44,10 @@ public interface LookupRegistry<T> {
     /**
      * Looks up an object matching the given request path.
      *
      * @param path the request path
      * @return object or {@code null} if no match is found.
      */
-    T lookup(String string);
+    T lookup(String value);
 
     /**
      * Removes registered object, if exists, for the given pattern.
@@ -44,10 +44,10 @@ public interface LookupRegistry<T> {
      * Looks up an object matching the given request path.
      *
-     * @param path the request path
+     * @param value the request path
      * @return object or {@code null} if no match is found.
      */